## simple top-down shooting [Pyxel version]

#### Files include:

- app.py: main file where a World's child class `App` is implemented and run.
- component.py: `Component` examples (Movable, Position, Velocity, Playable, etc..)
- entity.py: Player and Enemy class with create method which create entity and add components to world.
- event.py: `Event` examples
- screen.py: `Screen` examples
- system.py: `System` examples
- actions.py: `ActionMap` examples

#### User guide:

1. Download this code.
1. install module dependency
    ```bash
    pip install -U pyxel pigframe
    ```
1. Run app.py
    ```bash
    python app.py
    ```